**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_Lauragais_targetMOTAD.gms
Sequence         3 - Risk and time in models
GAMS language    sqr, sqrt
Type             NLP
Description
A farm in the Lauragais, a region in south-western France, has 200 ha of farmland, 100 ha of which are irrigated.
A farmer and her husband work on this farm, both are skilled workers.
The farmer sells her production via a local agricultural cooperative which is very involved in the production and marketing of seeds.
It thus has the choice between two types of production :
arable crops for the human or animal feed market and seed crops produced under contract with the cooperative.
She can grow the following arable crops (for the human or animal feed market) : soft wheat, durum wheat, soya-bean and sunflower.
As for seed crops, she can grow maize and vegetable crops : cucumber, cabbage, sugar beet, carrot, onion and parsley.
Seed crops are much more profitable, but the quality requirements of the cooperative are very strict and certain years,
climatic conditions do not make it possible to meet the quality required by the specifications.
The price, which depends on quality, suffers the consequences. In some cases, the cooperative can turn down the entire harvest.
The gross margin of this production is therefore equal to zero.
Seed crops require unskilled labour for the harvest.
This work is entirely carried out by hired labour and must be supervised by a skilled worker (family-based or also hired).
One skilled worker is needed to supervise 20 unskilled workers. A hired worker costs 11.1/hour and a skilled worker 73.3/hour.
The fixed costs of the farm are 93293. The farmer can rent land to her neighbours at a rate of 519.
Costs for each crop are divided into three types : operating costs excluding labour-force, specific costs, and the costs of hired labour.
Crops do not require the same amount of labour every month of the year. Only arable crops call for skilled labour for mechanised tasks.
Seed crops require significant amounts of unskilled labour during the harvest period.
Selling prices are as follows : 25 for durum wheat, 14 for soft wheat, 35 for sunflower and 36 for soya-bean.
The objective of the farmer is to maximize her income.


Model Lauragais 1994
*reference: Jacquet F -Legrusse Ph- Risk in farmer decision-making :
*Combining economic and management approaches.
*Communication au 38eme seminaire de l'AEEA, Copenhague, novembre 1994
$offtext

*-----------------------------------------------------------------------------*


*----------                          DECLARATIONS                        ----------*

SETS
C        Crops                  /durum_wheat,soft_wheat,sunflower,soya-bean,maize_S,
                                 sugar_beet_S,cucumber_S,carrot_S,onion_S,cabbage_S,parsley_S/
IC(C)    Irrigable crops        /maize_S,soya-bean,sugar_beet_S,cucumber_S,carrot_S,onion_S,cabbage_S,parsley_S/
SC(C)    Seed crops             /sugar_beet_S,cucumber_S,carrot_S,onion_S,cabbage_S,parsley_S/
M        Month                  /M1*M12/
E        states of nature       /E1* E10/
sce      scenario               /sc1*sc5/
;

*----------                          DATA                        ----------*
*---------------------monetary values are in euros     --------------------*

SCALARS

SAF      surface area of the farm in hectares                  /200/
ISAF     irrigable surface                                     /100/
NFM      number of family workers (skilled)                      /2/
PML      price manual labour (unskilled)                      /11.1/
PLC      price of labour provided by a company (qualified)    /73.3/
FC       Fixed costs                                         /93293/
RP       rental price (land rental)                            /519/
S        upervision of the workforce                          /0.05/
Z0       minimal income
LBD      it measures the average deviation tolerated          /5000/
;


parameter
Min_Inc(sce) different minimum income
/sc1 -1000000, sc2 0, sc3 70000, sc4 110000, sc5 160000/


PARAMETERS

OC(C) operational costs excluding labour in  per ha
/
durum_wheat        379
soft_wheat         379
sunflower          258
soya-bean          777
maize_S           1814
sugar_beet_s      3369
cucumber_s        1175
carrot_s          1743
onion_s           3964
cabbage_s         3109
parsley_s          826
/

Sp_Costs(C) specific costs per crop in  per ha
/
durum_wheat        488
soft_wheat         488
sunflower          488
soya-bean          488
maize_S            488
sugar_beet_s      1244
cucumber_s        1244
carrot_s          1244
onion_s           1244
cabbage_s         1244
parsley_s         1244
/

ALABOUR(M) total available labour hours in hours per NFM
/m1 112,m2 120,m3 104,m4 112,m5 104,m6 136,
m7 160,m8 144,m9 152,m10 136,m11 128,m12 128/

PI(C)  price (in euros per quintal) or revenue for seeds
/
durum_wheat        23.5
soft_wheat         14
sunflower          35
soya-bean          36
maize_S             1
sugar_beet_s        1
cucumber_s          1
carrot_s            1
onion_s             1
cabbage_s           1
parsley_s           1
/


TABLE
MLabour(c,m)      needs in mechanized labour for field crop work (qualified) (in hours per ha)
               m1   m2   m3   m4    m5  m6   m7   m8   m9   m10  m11    m12
durum_wheat     1  0.5  0.5  0.5   0.5      1.5       0.5  1.5   2.5   0.5
soft_wheat      1  0.5  0.5  0.5   0.5      1.5       0.5  1.5   2.5   0.5
sunflower          1.5  1.5  2     1                             2
maize_S         0  1    1    4.5   3    2   3.5   2    1    0    2      0
soya-bean       0  1.5  1.5  1     1.5  1.5 2     0.5  0    1
;

TABLE
U_MLabour(c,m)   needs for unskilled manual labour (in hours per ha)
                 m1   m2   m3   m4    m5  m6  m7   m8   m9  m10  m11  m12
maize_S                                       120
sugar_beet_s     50        5    5     5    5   5    5    5    5
cucumber_s                            5    5   5    5       100
carrot_s                   5    5     5    5   5    5              5    5
onion_s                                   120       80
cabbage_s                                 100      100
parsley_s                  5    5     5

;

TABLE Yld(C,E) yields in quintals for cereals and in euros for seeds
                   E1       E2       E3       E4       E5       E6       E7       E8       E9       E10
durum_wheat        68      76.5      73.1     76.5     74.8     73.1     71.4     76.5     74.8     66.3
soft_wheat         59.5    76.5      73.1     68       74.8     79.9     74.8     73.1     69.7     81.6
sunflower          49.3    47.6      42.5     45.9     44.2     49.3     34       42.5     45.9     30.6
soya-bean          47.6    49.3      45.9     49.3     47.6     34       45.9     47.6     44.2     51
maize_S          6477     7774     6997      389     3888     6477    10367     9122     8293    10185
sugar_beet_s        0     9503     8553     6479    11662     3109     9071     6479    13476    17192
cucumber_s        726     9433     7257        0    13994     8293     7257     8034    11662     5909
carrot_s            0     7257     5806     9848      376     9848     8811     6479     6997     2630
onion_s         13994    10367     9330    11662    14773    11662        0     9071     9071     3369
cabbage_s        7237    15550    11662    16845    22029    13994        0    16845     8293     4146
parsley_s           0     7252     5076     6479     8293     5702     3499     5442     3888     5137
;

parameter Avrg_Yield ;
Avrg_Yield(C)=sum(E, Yld(C,E)/card(E));
display Avrg_Yield;

parameter CostUN;
CostUN(C)=sum(M,U_MLabour(C,M)*PML);
display CostUN;


*----------                         CALCULATIONS                          ----------*
parameter RGM(C,E) random gross margin ;
RGM(C,E)=Yld(C,E)*PI(C)-OC(C)-sum(m,U_MLabour(c,m)*PML);

parameter GM(c) average gross margin per crop ;
GM(c)= sum[e, Yld(C,E)*PI(C)]/card(E)-Sp_Costs(C) - OC(C) - sum[m,U_MLabour(c,m)*PML] ;

*----------                         MODEL                          ----------*


 VARIABLES
 Z        objective
 I        global income
 SDI      standard deviation of income
 X(C)     area per crop
 H        land rental
 T(m)     company work
 RI(E)    rabdom income
 DEV(E)   it measures the deviation below Z0

 ;
POSITIVE VARIABLES X,T,H,DEV ;

EQUATION
Objective         objective function
Income            income
SD_Income         standard deviation of income
land              land equation
skilled_labour(m) skilled labour equation
Irrig             equation of availability in irrigable land
random_income(E)  equation for calculating random income

deviation(E)      deviation from the minimum income
lambda            equation that limits the weighted sum of the deviations
;

 objective ..              I =e= Z;

 Income ..                 sum[C,X(C)*GM(C)]-sum[m,T(m)*plc]-H*RP-FC =e=I ;
*total gross margins less specific costs - total price of salaried labour less price of land rental less fixed costs

 land ..                   sum(C,X(C))=l=SAF+H;

 Irrig ..                  sum(IC,x(IC))=l=ISAF;
*the sum of the areas of irrigable crops must be less than the availability of irrigable surfaces.

 skilled_labour(m) ..      sum(C,MLabour(C,M)*x(C))+sum(C,U_MLabour(C,M)*x(C)*s) =l= ALABOUR(M)*NFM+T(M);
*per month[total mechanized labour and supervision of total manual labour
*must be less than [family skilled labour multiplied by NFM number plus qualified company labour]

 random_income(E)..        sum(C,X(C)*(RGM(C,E)-Sp_Costs(C)))-sum(M,T(M)*plc)-H*RP-FC=e=RI(E);
*for each state of nature, calculation of income

 SD_Income ..              sqrt (sum (E, sqr(RI(E)-I))/card(E))=e= SDI;

 deviation(E)..   z0-DEV(E) =l= RI(E) ;

 lambda..         sum(E,DEV(E)/card(E)) =l= LBD ;

Model lauragais /ALL/ ;

*----------                        SOLUTION                         ----------*


parameter result(*,*,*);
LOOP(sce, Z0=Min_Inc(sce);
SOLVE lauragais USING NLP MAXIMIZING Z ;

result(C,'HA',sce)=X.L(C);
result('SAF','HA',sce)=sum(c,X.L(C));
result('locter','HA',sce)=H.L;
result('Min_Inc','',sce)=z0;
result('Average_Income','EUROS',sce)=I.L;
result('INCOME',E,sce)=RI.L(E);
result('SD_income','EUROS',sce)=SDI.L;
result('labour','Hours_year',sce)=sum(m,t.L(m));
result('model','status',sce)= lauragais.modelStat ;
);
option result:2:2:1;

display result,GM,RGM, Avrg_Yield;

 ;

